@@ -5,7 +5,7 @@ use futures_core::future::BoxFuture;
 use rbatis_core::Error;
 use serde::de::DeserializeOwned;
 use serde::{Deserialize, Serialize};
-use bson2::Bson;
+use rbson::Bson;
 
 use crate::core::db::DriverType;
 use crate::sql::PageLimit;
@@ -24,7 +24,7 @@ pub trait PagePlugin: Send + Sync + Debug {
         &self,
         driver_type: &DriverType,
         sql: &str,
-        args: &Vec<bson2::Bson>,
+        args: &Vec<rbson::Bson>,
         page: &dyn IPageRequest,
     ) -> Result<(String, String), crate::core::Error>;
 }
@@ -168,17 +168,6 @@ impl IPageRequest for PageRequest {
     }
 }
 
-impl ToString for PageRequest {
-    fn to_string(&self) -> String {
-        let result = serde_json::to_string(self);
-        if result.is_err() {
-            return String::new();
-        } else {
-            return result.unwrap();
-        }
-    }
-}
-
 impl<T> Page<T> {
     pub fn new(current: u64, page_size: u64) -> Self {
         return Page::new_total(current, page_size, 0);
@@ -276,19 +265,6 @@ impl<T> IPage<T> for Page<T>
     }
 }
 
-impl<T> ToString for Page<T>
-    where
-        T: Send + Sync + Serialize,
-{
-    fn to_string(&self) -> String {
-        let result = serde_json::to_string(self);
-        if result.is_err() {
-            return String::new();
-        } else {
-            return result.unwrap();
-        }
-    }
-}
 
 ///use Replace page plugin
 #[derive(Copy, Clone, Debug)]
