@@ -7,7 +7,6 @@ use once_cell::sync::OnceCell;
 use rbatis_core::db::DBConnectOption;
 use serde::de::DeserializeOwned;
 use serde::ser::Serialize;
-use serde_json::Number;
 use uuid::Uuid;
 
 use crate::core::db::{DBExecResult, DBPool, DBPoolConn, DBPoolOptions, DBQuery, DBTx, DriverType};
@@ -39,7 +38,7 @@ pub struct Rbatis {
     // logic delete plugin
     pub logic_plugin: Option<Box<dyn LogicDelete>>,
     // sql param binder
-    pub encoder: fn(q: &mut DBQuery, arg: bson2::Bson) -> crate::Result<()>,
+    pub encoder: fn(q: &mut DBQuery, arg: rbson::Bson) -> crate::Result<()>,
 }
 
 impl Debug for Rbatis {
